/*
 * Example for GainAMP click
 *
 * Date         Jan 2017
 * Author       Marton B.
 * Copyright    GNU Public License v2
 *
 * Test configuration STM32 :
 *  MCU           :	STM32F107VCT6
 *  Dev. Board    :	EasyMx PRO v7 for STM32 ARM
 *  SW            :	mikroC PRO for ARM v4.9.0
 *
 * Include example.pld file in your project.
 *
 ******************************************************************************/

#include "gain_amp.h"

sbit GAIN_AMP_CS at GPIOD_ODR.B13;
sbit GAIN_AMP_SHDN at GPIOC_ODR.B2;

static uint8_t gain;
static uint8_t byte;

static void system_init( void );


static void system_init( void )
{
    GPIO_Digital_Output( &GPIOD_BASE, _GPIO_PINMASK_13 );
    GPIO_Digital_Output( &GPIOC_BASE, _GPIO_PINMASK_2 );
    GAIN_AMP_CS = 1;

    GPIO_Digital_Input( &GPIOE_BASE, _GPIO_PINMASK_9 );
    GPIO_Digital_Input( &GPIOE_BASE, _GPIO_PINMASK_8 );

    GPIO_Digital_Output( &GPIOD_BASE, _GPIO_PINMASK_LOW );

    SPI3_Init_Advanced( 
        _SPI_FPCLK_DIV16, 
        _SPI_MASTER | 
        _SPI_8_BIT |
        _SPI_CLK_IDLE_HIGH |
        _SPI_FIRST_CLK_EDGE_TRANSITION |
        _SPI_MSB_FIRST |
        _SPI_SS_DISABLE |
        _SPI_SSM_ENABLE |
        _SPI_SSI_1, &_GPIO_MODULE_SPI3_PC10_11_12
    );

    gain_amp_init( SPI3_Write );

    gain = 0;
}

void main()
{
    system_init();

    gain_amp_set(GAIN_AMP_NOMINAL_0, GAIN_AMP_SW_SHUTDOWN);

    while( 1 )
    {
        if(Button(&GPIOE_IDR, 9, 100, 1)) 
        {
            byte = gain_amp_set(++gain & 0x07, GAIN_AMP_SW_SHUTDOWN);
            GPIOD_ODR = (GPIOD_ODR & 0xFF00) | byte;
        }
        if(Button(&GPIOE_IDR, 8, 100, 1)) 
        {
            byte = gain_amp_set(--gain & 0x07, GAIN_AMP_SW_SHUTDOWN);
            GPIOD_ODR = (GPIOD_ODR & 0xFF00) | byte;
        }
    }
}

/************************************************************ END OF FILE *****/